aboutsummaryrefslogtreecommitdiff
path: root/cast/sender/public/cast_app_discovery_service.h
diff options
context:
space:
mode:
Diffstat (limited to 'cast/sender/public/cast_app_discovery_service.h')
-rw-r--r--cast/sender/public/cast_app_discovery_service.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/cast/sender/public/cast_app_discovery_service.h b/cast/sender/public/cast_app_discovery_service.h
index c05d66bd..2e095b6d 100644
--- a/cast/sender/public/cast_app_discovery_service.h
+++ b/cast/sender/public/cast_app_discovery_service.h
@@ -7,19 +7,19 @@
#include <vector>
-#include "cast/common/public/service_info.h"
+#include "cast/common/public/receiver_info.h"
namespace openscreen {
namespace cast {
class CastMediaSource;
// Interface for app discovery for Cast devices.
class CastAppDiscoveryService {
public:
using AvailabilityCallback =
std::function<void(const CastMediaSource& source,
- const std::vector<ServiceInfo>& devices)>;
+ const std::vector<ReceiverInfo>& receivers)>;
class Subscription {
public:
@@ -47,7 +47,7 @@ class CastAppDiscoveryService {
// returned via |callback| until the returned Subscription is destroyed by the
// caller. If there are cached results available, |callback| will be invoked
// before this method returns. |callback| may be invoked with an empty list
- // if all devices respond to the respective queries with "unavailable" or
+ // if all receivers respond to the respective queries with "unavailable" or
// don't respond before a timeout. |callback| may be invoked successively
// with the same list.
virtual Subscription StartObservingAvailability(
@@ -7,19 +7,19 @@
namespace cast {
class CastMediaSource;
-// Interface for app discovery for Cast devices.
+// Interface for app discovery for Cast receivers.
class CastAppDiscoveryService {
public: